@@ -30,10 +30,8 @@ from .lawkit import (
     LawType,
 )
 
-# For backward compatibility and convenience
-from .compat import run_lawkit
 
-__version__ = "2.1.0"
+__version__ = "2.3.0"
 __all__ = [
     # Main analysis functions
     "analyze_benford",
@@ -61,6 +59,4 @@ __all__ = [
     "OutputFormat", 
     "LawType",
     
-    # Backward compatibility
-    "run_lawkit",
 ]
\ No newline at end of file
